using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using ZylGPSReceiverMobile;

namespace CSharpDemo
{
    public partial class FormMain : Form
    {
        public FormMain()
        {
            InitializeComponent();
        }

        // This delegate enables asynchronous calls for setting
        // the text property on a TextBox control.
        private delegate void SetTextCallback(string text);

        private void Set_textBoxOut(string text)
        {
            try
            {
                // InvokeRequired required compares the thread ID of the
                // calling thread to the thread ID of the creating thread.
                // If these threads are different, it returns true.
                if (this.InvokeRequired)
                {
                    this.Invoke(new SetTextCallback(Set_textBoxOut),
                        new object[] { text });
                    return;


                }

                this.textBoxOut.Text += text;
                this.textBoxOut.SelectionStart = textBoxOut.Text.Length;
                this.textBoxOut.SelectionLength = 0;
                this.textBoxOut.ScrollToCaret();
            }
            catch
            {
                this.textBoxOut.Text = string.Empty;
            }
        }

        private void Set_textBoxCoord(string text)
        {
            try
            {
                // InvokeRequired required compares the thread ID of the
                // calling thread to the thread ID of the creating thread.
                // If these threads are different, it returns true.
                if (this.InvokeRequired)
                {
                    this.Invoke(new SetTextCallback(Set_textBoxCoord),
                        new object[] { text });
                    return;


                }

                this.textBoxCoord.Text = text;
            }
            catch { }
        }


        private void btnClose_Click(object sender, EventArgs e)
        {
            cmpGpsReceiver.Close();
        }

        private void btnOpen_Click(object sender, EventArgs e)
        {
            if (lstPorts.SelectedIndex >= 0)
            {
                cmpGpsReceiver.Port = (SerialCommPort)(lstPorts.SelectedIndex + 1);
                if (!cmpGpsReceiver.Open())
                    MessageBox.Show("Cannot open.");                
            }
        }

        private void cmpGpsReceiver_Received(object sender, ZylGPSReceiverMobile.DataEventArgs e)
        {
            string str;
            str = "Lat: " + cmpGpsReceiver.Position.GetLatitudeAsDecimalDegrees().ToString() + " ";
            str += "Long: " + cmpGpsReceiver.Position.GetLongitudeAsDecimalDegrees().ToString() + " ";
            str += "Alt: " + cmpGpsReceiver.Position.Altitude.ToString() + " ";
            str += "Speed: " + cmpGpsReceiver.Position.Speed_KMH.ToString();
            Set_textBoxCoord(str);
            Set_textBoxOut(e.Buffer);    
        }

        private void cmpGpsReceiver_Connected(object sender, ZylGPSReceiverMobile.ConnectionEventArgs e)
        {
            Set_textBoxOut("Connected to: " + e.Port.ToString());
        }

        private void cmpGpsReceiver_Disconnected(object sender, ZylGPSReceiverMobile.ConnectionEventArgs e)
        {
            Set_textBoxOut("Disconnected from: " + e.Port.ToString());
        }
    }
}